==> esp32c3-0.3.0.crate: esp32c3-0.3.0/src/apb_saradc/sar1_status.rs <==
#[doc = "Register `SAR1_STATUS` reader"]
pub struct R(crate::R<SAR1_STATUS_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SAR1_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SAR1_STATUS_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SAR1_STATUS_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `SARADC_SAR1_STATUS` reader - saradc1 status about data and channel"]
pub struct SARADC_SAR1_STATUS_R(crate::FieldReader<u32, u32>);
impl SARADC_SAR1_STATUS_R {
    pub(crate) fn new(bits: u32) -> Self {
        SARADC_SAR1_STATUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SARADC_SAR1_STATUS_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - saradc1 status about data and channel"]
    #[inline(always)]
    pub fn saradc_sar1_status(&self) -> SARADC_SAR1_STATUS_R {
        SARADC_SAR1_STATUS_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
#[doc = "digital saradc configure register\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [sar1_status](index.html) module"]
pub struct SAR1_STATUS_SPEC;
impl crate::RegisterSpec for SAR1_STATUS_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [sar1_status::R](R) reader structure"]
impl crate::Readable for SAR1_STATUS_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets SAR1_STATUS to value 0"]
impl crate::Resettable for SAR1_STATUS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/apb_saradc/sar1_status.rs <==
#[doc = "Register `SAR1_STATUS` reader"]
pub struct R(crate::R<SAR1_STATUS_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<SAR1_STATUS_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<SAR1_STATUS_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<SAR1_STATUS_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `SARADC_SAR1_STATUS` reader - saradc1 status about data and channel"]
pub struct SARADC_SAR1_STATUS_R(crate::FieldReader<u32, u32>);
impl SARADC_SAR1_STATUS_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        SARADC_SAR1_STATUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for SARADC_SAR1_STATUS_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - saradc1 status about data and channel"]
    #[inline(always)]
    pub fn saradc_sar1_status(&self) -> SARADC_SAR1_STATUS_R {
        SARADC_SAR1_STATUS_R::new(self.bits)
    }
}
#[doc = "digital saradc configure register\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [sar1_status]
(index.html) module"]
pub struct SAR1_STATUS_SPEC;
impl crate::RegisterSpec for SAR1_STATUS_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [sar1_status::R]
(R) reader structure"]
impl crate::Readable for SAR1_STATUS_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets SAR1_STATUS to value 0"]
impl crate::Resettable for SAR1_STATUS_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
